@@ -24,10 +24,7 @@ Implementation Notes
   https://circuitpython.org/downloads
 * Adafruit's Bus Device library: https://github.com/adafruit/Adafruit_CircuitPython_BusDevice
 """
-try:
-    import struct
-except ImportError:
-    import ustruct as struct
+import struct
 
 from adafruit_bus_device.i2c_device import I2CDevice
 from micropython import const
